@@ -1,9 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
- * applicable.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -32,6 +32,10 @@
 #include <process.h>
 #endif
 
+#ifndef LOGON32_LOGON_NETWORK
+#define LOGON32_LOGON_NETWORK 3
+#endif
+
 #ifdef _WIN32_WCE
 #ifndef DETACHED_PROCESS
 #define DETACHED_PROCESS 0
@@ -201,6 +205,7 @@ APR_DECLARE(apr_status_t) apr_procattr_detach_set(apr_procattr_t *attr,
     return APR_SUCCESS;
 }
 
+#ifndef _WIN32_WCE
 static apr_status_t attr_cleanup(void *theattr)
 {
     apr_procattr_t *attr = (apr_procattr_t *)theattr;    
@@ -209,6 +214,7 @@ static apr_status_t attr_cleanup(void *theattr)
     attr->user_token = NULL;
     return APR_SUCCESS;
 }
+#endif
 
 APR_DECLARE(apr_status_t) apr_procattr_user_set(apr_procattr_t *attr, 
                                                 const char *username,
@@ -499,6 +505,9 @@ APR_DECLARE(apr_status_t) apr_proc_create(apr_proc_t *new,
     else 
 #endif
     {
+#if defined(_WIN32_WCE)
+        {
+#else
         /* Win32 is _different_ than unix.  While unix will find the given
          * program since it's already chdir'ed, Win32 cannot since the parent
          * attempts to open the program with it's own path.
@@ -556,6 +565,7 @@ APR_DECLARE(apr_status_t) apr_proc_create(apr_proc_t *new,
             }
         }
         else {
+#endif
             /* A simple command we are directly invoking.  Do not pass
              * the first arg to CreateProc() for APR_PROGRAM_PATH
              * invocation, since it would need to be a literal and
