@@ -1,8 +1,9 @@
-/* Copyright 2000-2004 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -138,7 +139,7 @@ APR_DECLARE(apr_status_t) apr_time_exp_lt(apr_time_exp_t *result,
 
     AprTimeToFileTime(&ft, input);
 
-#if APR_HAS_UNICODE_FS
+#if APR_HAS_UNICODE_FS && !defined(_WIN32_WCE)
     IF_WIN_OS_IS_UNICODE
     {
         TIME_ZONE_INFORMATION *tz;
@@ -177,7 +178,7 @@ APR_DECLARE(apr_status_t) apr_time_exp_lt(apr_time_exp_t *result,
                          - (-(tz->Bias + tz->StandardBias) / 60);
     }
 #endif
-#if APR_HAS_ANSI_FS
+#if APR_HAS_ANSI_FS || defined(_WIN32_WCE)
     ELSE_WIN_OS_IS_ANSI
     {
         TIME_ZONE_INFORMATION tz;
@@ -303,7 +304,13 @@ APR_DECLARE(void) apr_sleep(apr_interval_time_t t)
     Sleep((DWORD)(t / 1000));
 }
 
-
+#if defined(_WIN32_WCE)
+/* A noop on WinCE, like Unix implementation */
+APR_DECLARE(void) apr_time_clock_hires(apr_pool_t *p)
+{
+    return;
+}
+#else
 static apr_status_t clock_restore(void *unsetres)
 {
     ULONG newRes;
@@ -323,3 +330,4 @@ APR_DECLARE(void) apr_time_clock_hires(apr_pool_t *p)
                                   apr_pool_cleanup_null);
     }
 }
+#endif
